@@ -14,7 +14,7 @@ Written by Andreas Jung
 
 E-Mail: andreas@andreas-jung.com
 
-$Id: TextIndexNG.py,v 1.143 2004/03/23 06:54:39 ajung Exp $
+$Id: TextIndexNG.py,v 1.144 2004/04/01 06:26:49 ajung Exp $
 """
 
 import sys
@@ -217,9 +217,12 @@ class TextIndexNG(SimpleItem):
         wids = IISet()
 
         for attr in fields:
-            result = self._index_object(documentId, obj, threshold, attr)
-            if result is not None:
-                wids = union(wids, result)
+            try:
+                result = self._index_object(documentId, obj, threshold, attr)
+                if result is not None:
+                    wids = union(wids, result)
+            except:
+                pass
 
         # get rid of words removed by reindexing
         try:
