@@ -1,6 +1,6 @@
 # check for converter modules
 
-import os
+import os, popen2
 from commands import getoutput
 
 from zLOG import LOG, INFO, WARNING
@@ -19,14 +19,15 @@ for cv in converters:
     for t in converter.getType():
         depends_on = getattr(converter, 'depends_on', None)
         if depends_on and os.name == 'posix':
-            out = getoutput('which %s' % depends_on)
+            r,w,e = popen2.popen3('which %s' % depends_on)
+            out = r.read() + e.read()
             if out.find('no %s' % depends_on) > - 1 or out.lower().find('not found') > -1 or len(out.strip()) == 0:
                 LOG('textindexng', WARNING, 'Converter "%s" not registered because executable "%s" could not be found' % (cv, depends_on))
             else:
-                LOG('textindexng', INFO, 'Converter "%s" registered' % cv)
                 ConverterRegistry.register(t, converter)
+                LOG('textindexng', INFO, 'Converter "%s" for %s registered' % (cv, t))
         else:
-            LOG('textindexng', INFO, 'Converter "%s" registered' % cv)
             ConverterRegistry.register(t, converter)
+            LOG('textindexng', INFO, 'Converter "%s" for %s registered' % (cv, t))
 
 del converters
