@@ -1,5 +1,10 @@
-
+#if UNICODE_SIZE==1
+typedef unsigned char symbol;
+#elif UNICODE_SIZE==2
 typedef unsigned short symbol;
+#else
+typedef unsigned int symbol;
+#endif
 
 /* Or replace 'char' above with 'short' for 16 bit characters.
 
